@@ -6,10 +6,12 @@ SPDX-License-Identifier: Apache-2.0
 
 # cdk-nag
 
-| Language   | cdk-nag                                                                                   | monocdk-nag                                                                                       |
-| ---------- | ----------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------- |
-| Python     | [![PyPI version](https://badge.fury.io/py/cdk-nag.svg)](https://badge.fury.io/py/cdk-nag) | [![PyPI version](https://badge.fury.io/py/monocdk-nag.svg)](https://badge.fury.io/py/monocdk-nag) |
-| TypeScript | [![npm version](https://badge.fury.io/js/cdk-nag.svg)](https://badge.fury.io/js/cdk-nag)  | [![npm version](https://badge.fury.io/js/monocdk-nag.svg)](https://badge.fury.io/js/monocdk-nag)  |
+| Language   | cdk-nag                                                                                                                         | monocdk-nag                                                                                                                             |
+| ---------- | ------------------------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------- |
+| Python     | [![PyPI version](https://img.shields.io/pypi/v/cdk-nag)](https://pypi.org/project/cdk-nag/)                                     | [![PyPI version](https://img.shields.io/pypi/v/monocdk-nag)](https://pypi.org/project/monocdk-nag/)                                     |
+| TypeScript | [![npm version](https://img.shields.io/npm/v/cdk-nag)](https://www.npmjs.com/package/cdk-nag)                                   | [![npm version](https://img.shields.io/npm/v/monocdk-nag/latest-1?label=npm)](https://www.npmjs.com/package/monocdk-nag)                |
+| Java       | [![Maven version](https://img.shields.io/maven-central/v/io.github.cdklabs/cdknag)](https://search.maven.org/search?q=a:cdknag) | [![Maven version](https://img.shields.io/maven-central/v/io.github.cdklabs/monocdknag)](https://search.maven.org/search?q=a:monocdknag) |
+| .NET       | [![NuGet version](https://img.shields.io/nuget/v/Cdklabs.CdkNag)](https://www.nuget.org/packages/Cdklabs.CdkNag)                | [![NuGet version](https://img.shields.io/nuget/v/Cdklabs.MonocdkNag)](https://www.nuget.org/packages/Cdklabs.MonocdkNag)                |
 
 * If your project uses cdk version **1.x.x** use `cdk-nag` **^1.0.0**
 * If your project uses cdk version **2.x.x** use `cdk-nag` **^2.0.0**
@@ -226,6 +228,13 @@ export class CdkTestStack extends Stack {
         resources: ['*'],
       })
     );
+    const thirdUser = new User(this, 'rSecondUser');
+    thirdUser.addToPolicy(
+      new PolicyStatement({
+        actions: ['sqs:CreateQueue'],
+        resources: [`arn:aws:sqs:${this.region}:${this.account}:*`],
+      })
+    );
     NagSuppressions.addResourceSuppressions(
       firstUser,
       [
@@ -248,6 +257,21 @@ export class CdkTestStack extends Stack {
       ],
       true
     );
+    NagSuppressions.addResourceSuppressions(
+      thirdUser,
+      [
+        {
+          id: 'AwsSolutions-IAM5',
+          reason: 'Suppress AwsSolutions-IAM5 on the SQS resource.',
+          appliesTo: [
+            {
+              regex: '/^Resource::arn:aws:sqs:(.*):\\*$/g',
+            },
+          ],
+        },
+      ],
+      true
+    );
   }
 }
 ```
@@ -884,7 +908,7 @@ class NagPackSuppression:
         *,
         id: builtins.str,
         reason: builtins.str,
-        applies_to: typing.Optional[typing.Sequence[builtins.str]] = None,
+        applies_to: typing.Optional[typing.Sequence[typing.Union[builtins.str, "RegexAppliesTo"]]] = None,
     ) -> None:
         '''Interface for creating a rule suppression.
 
@@ -914,10 +938,12 @@ class NagPackSuppression:
         return typing.cast(builtins.str, result)
 
     @builtins.property
-    def applies_to(self) -> typing.Optional[typing.List[builtins.str]]:
+    def applies_to(
+        self,
+    ) -> typing.Optional[typing.List[typing.Union[builtins.str, "RegexAppliesTo"]]]:
         '''Rule specific granular suppressions.'''
         result = self._values.get("applies_to")
-        return typing.cast(typing.Optional[typing.List[builtins.str]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[builtins.str, "RegexAppliesTo"]]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1070,6 +1096,40 @@ class PCIDSS321Checks(
         return typing.cast(None, jsii.invoke(self, "visit", [node]))
 
 
+@jsii.data_type(
+    jsii_type="monocdk-nag.RegexAppliesTo",
+    jsii_struct_bases=[],
+    name_mapping={"regex": "regex"},
+)
+class RegexAppliesTo:
+    def __init__(self, *, regex: builtins.str) -> None:
+        '''A regular expression to apply to matching findings.
+
+        :param regex: An ECMA-262 regex string.
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "regex": regex,
+        }
+
+    @builtins.property
+    def regex(self) -> builtins.str:
+        '''An ECMA-262 regex string.'''
+        result = self._values.get("regex")
+        assert result is not None, "Required property 'regex' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "RegexAppliesTo(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 class AwsSolutionsChecks(
     NagPack,
     metaclass=jsii.JSIIMeta,
@@ -1221,6 +1281,7 @@ __all__ = [
     "NagRules",
     "NagSuppressions",
     "PCIDSS321Checks",
+    "RegexAppliesTo",
 ]
 
 publication.publish()
